==> zcbot-crawl-core-0.0.1.tar.gz: zcbot-crawl-core-0.0.1/zcbot_crawl_core/dao/base.py <==
# -*- coding: utf-8 -*-
from typing import List
from ..client.mongo_client import Mongo


# 获取链接分拣规则配置
def get_url_parse_rule(host: str = None):
    if host:
        return Mongo().get('zcbot_url_parse_rule', {'_id': host})

    return Mongo().list('zcbot_url_parse_rule')


# 获取支持网站平台
def get_platforms():
    return Mongo().list('zcbot_platforms', sort=[('sort', 1)])


# # 获取支持网站平台
# def get_support_platforms_by_group(group_code: str, enable: int = None):
#     _query = {}
#     if group_code:
#         _query["group_code"] = group_code
#     if enable is not None:
#         _query["enable"] = enable
#
#     return mongo.list('zcbot_batch_spider_group', query=_query)


# 根据爬虫组编号，获取可选的爬虫清单
def get_support_spiders_by_group(group_code: str = None, plat_codes: List[str] = None, enable: int = None):
    _query = {}
    if group_code:
        _query["groupCode"] = group_code
    if plat_codes and len(plat_codes):
        _query["platCode"] = {"$in": plat_codes}
    if enable is not None:
        _query["enable"] = enable

    return Mongo().list('zcbot_batch_spider_group', query=_query)


# 根据爬虫组编号，获取爬虫组清单
def get_spider_group_list(group_code: str = None, plat_codes: List[str] = None, enable: int = None):
    _query = {}
    if group_code:
        _query["groupCode"] = group_code
    if plat_codes and len(plat_codes):
        _query["platCode"] = {"$in": plat_codes}
    if enable is not None:
        _query["enable"] = enable

    return Mongo().list('zcbot_batch_spider_group', query=_query)

#
# def get_platforms_by_group_code(group_code):
#     _query = {
#         "group_code": group_code
#     }
#     _fields = {
#         "spiders": 0,
#         "_id": 0
#     }
#     # return mongo.list('zcbot_batch_spider_group', query=_query, fields=_fields)
#     return mongo.aggregate('zcbot_platforms', [
#         {
#             '$lookup': {
#                 'from': 'zcbot_batch_spider_group',
#                 'localField': '_id',
#                 'foreignField': 'plat_code',
#                 'as': 'spider'
#             }
#         },
#         {
#             '$match': {'spider.group_code': group_code}
#         },
#         {
#             '$project': {'spider': 0}
#         },
#         {'$sort': {'sort': 1}}
#     ])

==> zcbot-crawl-core-0.0.2.tar.gz: zcbot-crawl-core-0.0.2/zcbot_crawl_core/dao/base.py <==
# -*- coding: utf-8 -*-
from typing import List
from ..client.mongo_client import Mongo


# 获取链接分拣规则配置
def get_url_parse_rule(host: str = None):
    if host:
        return Mongo().get('zcbot_url_parse_rule', {'_id': host})

    return Mongo().list('zcbot_url_parse_rule')


# 获取支持网站平台
def get_platforms():
    return Mongo().list('zcbot_platforms', sort=[('sort', 1)])


# 获取支持网站平台
def get_platforms_by_group(group_code: str, enable: int = None):
    _query = {}
    if group_code:
        _query["group_code"] = group_code
    if enable is not None:
        _query["enable"] = enable

    return Mongo().list('zcbot_batch_spider_group', query=_query)


# 根据爬虫组编号，获取可选的爬虫清单
def get_spiders_by_group(group_code: str = None, plat_codes: List[str] = None, enable: int = None):
    _query = {}
    if group_code:
        _query["groupCode"] = group_code
    if plat_codes and len(plat_codes):
        _query["platCode"] = {"$in": plat_codes}
    if enable is not None:
        _query["enable"] = enable

    return Mongo().list('zcbot_batch_spider_group', query=_query)


# 根据爬虫组编号，获取爬虫组清单
def get_spider_group_list(group_code: str = None, plat_codes: List[str] = None, enable: int = None):
    _query = {}
    if group_code:
        _query["groupCode"] = group_code
    if plat_codes and len(plat_codes):
        _query["platCode"] = {"$in": plat_codes}
    if enable is not None:
        _query["enable"] = enable

    return Mongo().list('zcbot_batch_spider_group', query=_query)

#
# def get_platforms_by_group_code(group_code):
#     _query = {
#         "group_code": group_code
#     }
#     _fields = {
#         "spiders": 0,
#         "_id": 0
#     }
#     # return mongo.list('zcbot_batch_spider_group', query=_query, fields=_fields)
#     return mongo.aggregate('zcbot_platforms', [
#         {
#             '$lookup': {
#                 'from': 'zcbot_batch_spider_group',
#                 'localField': '_id',
#                 'foreignField': 'plat_code',
#                 'as': 'spider'
#             }
#         },
#         {
#             '$match': {'spider.group_code': group_code}
#         },
#         {
#             '$project': {'spider': 0}
#         },
#         {'$sort': {'sort': 1}}
#     ])
